@@ -4,7 +4,7 @@ import audobject.core.define as define
 class config:
     r"""Get/set configuration values for the :mod:`audobject` module.
 
-    Example:
+    Examples:
 
         >>> config.PACKAGE_MISMATCH_WARN_LEVEL
         1
